@@ -6,6 +6,7 @@
 {-# LANGUAGE MultiParamTypeClasses            #-}
 {-# LANGUAGE TypeFamilies                     #-}
 
+-- | Internals of AES.
 module Raaz.Cipher.AES.Internal
        (-- * AES cipher.
          AES(..)
@@ -56,15 +57,15 @@ instance Encodable KEY128
 instance Encodable KEY192
 instance Encodable KEY256
 
-instance Random KEY128 where
-  random = unsafeStorableRandom
+instance RandomStorable KEY128 where
+  fillRandomElements = unsafeFillRandomElements
 
 
-instance Random KEY192 where
-  random = unsafeStorableRandom
+instance RandomStorable KEY192 where
+  fillRandomElements = unsafeFillRandomElements
 
-instance Random KEY256 where
-  random = unsafeStorableRandom
+instance RandomStorable KEY256 where
+  fillRandomElements = unsafeFillRandomElements
 
 -- | Expects in base 16
 instance IsString KEY128 where
@@ -96,8 +97,9 @@ instance Show KEY256 where
 newtype IV  = IV (TUPLE 4) deriving (Storable, EndianStore)
 
 instance Encodable IV
-instance Random IV where
-  random = unsafeStorableRandom
+
+instance RandomStorable IV where
+  fillRandomElements = unsafeFillRandomElements
 
 -- | Expects in base16.
 instance IsString IV where
@@ -177,8 +179,12 @@ aes128ctr = AES
 
 --------------  Memory for storing extended keys ---------
 
+-- | Extended key for aes128
 newtype EKEY128 = EKEY128 (TUPLE 44) deriving (Storable, EndianStore)
+-- | Extended key for aes192
 newtype EKEY192 = EKEY192 (TUPLE 52) deriving (Storable, EndianStore)
+
+-- | Extended key for aes256
 newtype EKEY256 = EKEY256 (TUPLE 60) deriving (Storable, EndianStore)
 
 instance Initialisable (MemoryCell EKEY128) KEY128 where
