@@ -18,7 +18,7 @@ module Raaz.Hash
        , HMAC, hmac, hmacFile, hmacSource
          -- * Exposing individual hashes.
          -- $individualHashes$
-
+       , module Raaz.Hash.Blake2
        , module Raaz.Hash.Sha224
        , module Raaz.Hash.Sha256
        , module Raaz.Hash.Sha384
@@ -28,6 +28,8 @@ module Raaz.Hash
        ) where
 
 -- import Raaz.Hash.Blake256
+
+import Raaz.Hash.Blake2
 import Raaz.Hash.Sha224
 import Raaz.Hash.Sha256
 import Raaz.Hash.Sha384
@@ -38,12 +40,7 @@ import Raaz.Hash.Internal.HMAC ( HMAC, hmac, hmacFile, hmacSource )
 
 -- $computingHash$
 --
--- === NOTE: SHA1 is broken.
 --
--- SHA1 is no more available form this module, its use is highly
--- depreciated. If you want to use it for transition please import
--- Raaz.Hash.Sha1 specifically
-
 -- The cryptographic hashes provided by raaz give the following
 -- guarantees:
 --
@@ -60,6 +57,13 @@ import Raaz.Hash.Internal.HMAC ( HMAC, hmac, hmacFile, hmacSource )
 -- The functions `hash`, `hashFile`, and `hashSource` provide a rather
 -- high level interface for computing hashes. For hmacs the associated
 -- functions are `hmac`, `hmacFile`, and `hmacSource`
+--
+-- === NOTE: SHA1 is broken.
+--
+-- SHA1 is no more available form this module, its use is highly
+-- depreciated. If you want to use it for transition please import
+-- Raaz.Hash.Sha1 specifically
+
 
 -- $encoding$
 --
