@@ -15,7 +15,6 @@ binary instance etc.
 {-# LANGUAGE MultiParamTypeClasses      #-}
 {-# CFILES raaz/hash/sha1/portable.c    #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
-
 module Raaz.Hash.Sha224.Internal
        ( SHA224(..)
        ) where
@@ -46,4 +45,4 @@ instance Primitive SHA224 where
   type Implementation SHA224 = SomeHashI SHA224
 
 instance Hash SHA224 where
-  additionalPadBlocks _ = 1
+  additionalPadBlocks _ = toEnum 1
