@@ -6,6 +6,7 @@
 {-# LANGUAGE MultiParamTypeClasses      #-}
 {-# CFILES raaz/hash/sha1/portable.c    #-}
 
+-- | Internals of Sha256.
 module Raaz.Hash.Sha256.Internal
        ( SHA256(..)
        ) where
@@ -49,4 +50,4 @@ instance Primitive SHA256 where
   type Implementation SHA256 = SomeHashI SHA256
 
 instance Hash SHA256 where
-  additionalPadBlocks _ = 1
+  additionalPadBlocks _ = toEnum 1
