@@ -6,6 +6,7 @@
 {-# LANGUAGE MultiParamTypeClasses      #-}
 {-# CFILES raaz/hash/sha1/portable.c    #-}
 
+-- | Internals of Sha384.
 module Raaz.Hash.Sha384.Internal
        ( SHA384(..)
        ) where
@@ -36,4 +37,4 @@ instance Primitive SHA384 where
   type Implementation SHA384 = SomeHashI SHA384
 
 instance Hash SHA384 where
-  additionalPadBlocks _ = 1
+  additionalPadBlocks _ = toEnum 1
