@@ -6,6 +6,7 @@
 {-# LANGUAGE DataKinds                  #-}
 {-# CFILES raaz/hash/sha1/portable.c    #-}
 
+-- | Internals of Sha512.
 module Raaz.Hash.Sha512.Internal (SHA512(..)) where
 
 
@@ -49,4 +50,4 @@ instance Initialisable (HashMemory SHA512) () where
                                   ]
 
 instance Hash SHA512 where
-  additionalPadBlocks _ = 1
+  additionalPadBlocks _ = toEnum 1
