@@ -1,4 +1,6 @@
 {-# LANGUAGE ForeignFunctionInterface         #-}
+
+-- | Entropy based on arc4random_buf (OpenBSD/NetBSD etc).
 module Raaz.Entropy( getEntropy ) where
 
 import Control.Monad.IO.Class(MonadIO, liftIO)
@@ -7,7 +9,7 @@ import Raaz.Core.Types
 
 -- | The getrandom system call.
 foreign import ccall unsafe
-  "arc4random"
+  "arc4random_buf"
   c_arc4random :: Pointer      -- Message
                -> BYTES Int    -- number of bytes
                -> IO (BYTES Int)
