@@ -50,6 +50,16 @@ instance Arbitrary SHA512 where
 instance Arbitrary SHA384 where
   arbitrary = genEncodable
 
+instance Arbitrary BLAKE2b where
+  arbitrary = genEncodable
+
+instance Arbitrary BLAKE2s where
+  arbitrary = genEncodable
+
+---------------- Parameter block for Blake          -------------
+
+---------------- Arbitrary instaces of encoded data --------------
+
 instance Arbitrary Base16 where
   arbitrary =  (encodeByteString . pack) <$> listOf arbitrary
 
